@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 320
+#define gmic_version 324
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -207,6 +207,10 @@ namespace gmic_library {
 #define cimg_appname "gmic"
 #endif
 
+#ifdef gmic_is_parallel
+#define cimg_use_pthread
+#endif
+
 #define cimg_library gmic_library
 #define CImg gmic_image
 #define CImgList gmic_list
@@ -263,7 +267,9 @@ inline double gmic_mp_store(const double *const ptrs, const unsigned int siz,
 #elif cimg_OS==1
 #include <cerrno>
 #include <sys/resource.h>
+#if !defined(__NetBSD__) && !defined(cimg_use_pthread) && cimg_display!=1
 #include <sys/syscall.h>
+#endif
 #include <signal.h>
 
 #endif // #if cimg_OS==2
@@ -392,10 +398,10 @@ struct gmic {
                            const unsigned int *const variables_sizes=0);
 
   gmic& add_commands(const char *const data_commands, const char *const commands_file=0,
-                     const bool add_debug_info=false, unsigned int *count_new=0,
-                     unsigned int *count_replaced=0, bool *const is_entrypoint=0);
+                     const bool add_debug_info=false,
+                     unsigned int *count_new=0, unsigned int *count_replaced=0, bool *const is_main_=0);
   gmic& add_commands(std::FILE *const file, const char *const filename=0, const bool add_debug_info=false,
-                     unsigned int *count_new=0, unsigned int *count_replaced=0, bool *const is_entrypoint=0);
+                     unsigned int *count_new=0, unsigned int *count_replaced=0, bool *const is_main_=0);
 
   gmic_image<char> callstack2string(const bool _is_debug=false) const;
   gmic_image<char> callstack2string(const gmic_image<unsigned int>& callstack_selection,
@@ -475,13 +481,14 @@ struct gmic {
                       const unsigned int start, const unsigned int end);
 
   template<typename T>
-  gmic& _run(const gmic_list<char>& commands_line, gmic_list<T> &images, gmic_list<char> &images_names);
+  gmic& _run(const gmic_list<char>& commands_line, gmic_list<T> &images, gmic_list<char> &images_names,
+             const bool push_new_run);
 
   template<typename T>
   gmic& _run(const gmic_list<char>& commands_line, unsigned int& position, gmic_list<T>& images,
              gmic_list<char>&images_names, gmic_list<T>& parent_images, gmic_list<char>& parent_images_names,
              const unsigned int *const variables_sizes, bool *const is_noargs, const char *const parent_arguments,
-             const gmic_image<unsigned int> *const command_selection);
+             const gmic_image<unsigned int> *const command_selection, const bool push_new_run);
 
   // Class attributes.
   static const char *builtin_commands_names[];
@@ -496,13 +503,13 @@ struct gmic {
   gmic_image<void*> display_windows;
   gmic_image<char> status;
 
-  float focale3d, light3d_x, light3d_y, light3d_z, specular_lightness3d, specular_shininess3d, _progress, *progress;
+  float light3d_x, light3d_y, light3d_z, _progress, *progress;
   gmic_uint64 reference_time;
   unsigned int nb_dowhiles, nb_fordones, nb_foreachdones, nb_repeatdones, nb_carriages_default, nb_carriages_stdout,
     debug_filename, debug_line, cimg_exception_mode;
-  int verbosity, render3d, renderd3d, network_timeout;
-  bool allow_entrypoint, is_change, is_debug, is_running, is_start, is_return, is_quit, is_double3d, is_debug_info,
-    _is_abort, *is_abort, is_abort_thread;
+  int verbosity, network_timeout;
+  bool allow_main_, is_change, is_debug, is_running, is_start, is_return, is_quit, is_debug_info,
+    _is_abort, *is_abort, is_abort_thread, is_lbrace_command;
   const char *starting_commands_line;
 };
 
